@@ -109,6 +109,8 @@ for i in 0 1 2; do
     -reportDir:"${report_dir}" \
     -jdk:${JDK_TO_TEST} \
     -vmoption:-Dtest.boot.jdk=${BOOTJDK_HOME} \
+    -vmoption:-Duser.home=${AUTOPKGTEST_TMP} \
+    -vmoption:-Djava.io.tmpdir=${AUTOPKGTEST_TMP} \
     -vmoption:-XX:MaxRAMPercentage=25 \
     -e:NSS_DEFAULT_DB_TYPE=sql \
     ${on_retry:-} $@ \
